==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/JenkinsPipelineBuildStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class JenkinsPipelineBuildStrategyBuilder extends io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyFluentImpl<io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy,io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyBuilder>{
  public JenkinsPipelineBuildStrategyBuilder() {
    this(false);
  }
  public JenkinsPipelineBuildStrategyBuilder(java.lang.Boolean validationEnabled) {
    this(new JenkinsPipelineBuildStrategy(), validationEnabled);
  }
  public JenkinsPipelineBuildStrategyBuilder(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyFluent<?> fluent) {
    this(fluent, false);
  }
  public JenkinsPipelineBuildStrategyBuilder(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new JenkinsPipelineBuildStrategy(), validationEnabled);
  }
  public JenkinsPipelineBuildStrategyBuilder(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyFluent<?> fluent,io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy instance) {
    this(fluent, instance, false);
  }
  public JenkinsPipelineBuildStrategyBuilder(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyFluent<?> fluent,io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withEnv(instance.getEnv()); 
    fluent.withJenkinsfile(instance.getJenkinsfile()); 
    fluent.withJenkinsfilePath(instance.getJenkinsfilePath()); 
    this.validationEnabled = validationEnabled; 
  }
  public JenkinsPipelineBuildStrategyBuilder(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy instance) {
    this(instance,false);
  }
  public JenkinsPipelineBuildStrategyBuilder(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withEnv(instance.getEnv()); 
    this.withJenkinsfile(instance.getJenkinsfile()); 
    this.withJenkinsfilePath(instance.getJenkinsfilePath()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy build() {
    JenkinsPipelineBuildStrategy buildable = new JenkinsPipelineBuildStrategy(fluent.getEnv(),fluent.getJenkinsfile(),fluent.getJenkinsfilePath());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JenkinsPipelineBuildStrategyBuilder that = (JenkinsPipelineBuildStrategyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/JenkinsPipelineBuildStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class JenkinsPipelineBuildStrategyBuilder extends io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyFluentImpl<io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy,io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyBuilder>{
  public JenkinsPipelineBuildStrategyBuilder() {
    this(false);
  }
  public JenkinsPipelineBuildStrategyBuilder(java.lang.Boolean validationEnabled) {
    this(new JenkinsPipelineBuildStrategy(), validationEnabled);
  }
  public JenkinsPipelineBuildStrategyBuilder(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyFluent<?> fluent) {
    this(fluent, false);
  }
  public JenkinsPipelineBuildStrategyBuilder(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new JenkinsPipelineBuildStrategy(), validationEnabled);
  }
  public JenkinsPipelineBuildStrategyBuilder(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyFluent<?> fluent,io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy instance) {
    this(fluent, instance, false);
  }
  public JenkinsPipelineBuildStrategyBuilder(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyFluent<?> fluent,io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withEnv(instance.getEnv()); 
    fluent.withJenkinsfile(instance.getJenkinsfile()); 
    fluent.withJenkinsfilePath(instance.getJenkinsfilePath()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public JenkinsPipelineBuildStrategyBuilder(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy instance) {
    this(instance,false);
  }
  public JenkinsPipelineBuildStrategyBuilder(io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withEnv(instance.getEnv()); 
    this.withJenkinsfile(instance.getJenkinsfile()); 
    this.withJenkinsfilePath(instance.getJenkinsfilePath()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.JenkinsPipelineBuildStrategy build() {
    JenkinsPipelineBuildStrategy buildable = new JenkinsPipelineBuildStrategy(fluent.getEnv(),fluent.getJenkinsfile(),fluent.getJenkinsfilePath());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JenkinsPipelineBuildStrategyBuilder that = (JenkinsPipelineBuildStrategyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
